Module: Yard::Lint::Validators::Documentation::UndocumentedMethodArguments

Defined in:
lib/yard/lint/validators/documentation/undocumented_method_arguments.rb,
lib/yard/lint/validators/documentation/undocumented_method_arguments/config.rb,
lib/yard/lint/validators/documentation/undocumented_method_arguments/parser.rb,
lib/yard/lint/validators/documentation/undocumented_method_arguments/result.rb,
lib/yard/lint/validators/documentation/undocumented_method_arguments/validator.rb,
lib/yard/lint/validators/documentation/undocumented_method_arguments/messages_builder.rb

Overview

UndocumentedMethodArguments validator

Ensures that all method parameters are documented with ‘@param` tags. This validator checks that every parameter in a method signature has a corresponding `@param` documentation tag. This validator is enabled by default.

## Configuration

To disable this validator:

Documentation/UndocumentedMethodArguments:
  Enabled: false

Examples:

Bad - Missing @param tags

# Does something with data
def process(name, options)
end

Good - All parameters documented

# Does something with data
# @param name [String] the name to process
# @param options [Hash] configuration options
def process(name, options)
end

Defined Under Namespace

Classes: Config, MessagesBuilder, Parser, Result, Validator