Class: Yard::Lint::Validators::Documentation::UndocumentedBooleanMethods::Validator
- Inherits:
-
Base
- Object
- Base
- Yard::Lint::Validators::Documentation::UndocumentedBooleanMethods::Validator
- Defined in:
- lib/yard/lint/validators/documentation/undocumented_boolean_methods/validator.rb
Overview
Runs a query that will pick all the boolean methods (ending with ?) that do not have a return type or return description documented
Constant Summary
Constants inherited from Base
Instance Attribute Summary
Attributes inherited from Base
Method Summary
Methods inherited from Base
#call, clear_yard_database!, command_cache, #initialize, reset_command_cache!
Constructor Details
This class inherits a constructor from Yard::Lint::Validators::Base